This directory subtree contains Annalist data that describes bibliographic records, largeely in the style of BibJSON.

These files are not part of the core Annalist configuration, but they are used by parts of the test suite, as structures required for representing BibJSON were used to guide rearly development of Annalist capabilities.
